#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="MapiCalendarEventRecurrenceDto.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six
from typing import List, Set, Dict, Tuple, Optional
from datetime import datetime

from AsposeEmailCloudSdk.models.mapi_calendar_recurrence_pattern_dto import MapiCalendarRecurrencePatternDto
from AsposeEmailCloudSdk.models.mapi_calendar_time_zone_dto import MapiCalendarTimeZoneDto


class MapiCalendarEventRecurrenceDto(object):
    """Recurrence properties of calendar object.             
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'appointment_time_zone_definition_recur': 'MapiCalendarTimeZoneDto',
        'clip_end': 'datetime',
        'clip_start': 'datetime',
        'is_exception': 'bool',
        'recurrence_pattern': 'MapiCalendarRecurrencePatternDto',
        'time_zone_struct': 'MapiCalendarTimeZoneDto'
    }

    attribute_map = {
        'appointment_time_zone_definition_recur': 'appointmentTimeZoneDefinitionRecur',
        'clip_end': 'clipEnd',
        'clip_start': 'clipStart',
        'is_exception': 'isException',
        'recurrence_pattern': 'recurrencePattern',
        'time_zone_struct': 'timeZoneStruct'
    }

    def __init__(self, appointment_time_zone_definition_recur: MapiCalendarTimeZoneDto = None, clip_end: datetime = None, clip_start: datetime = None, is_exception: bool = None, recurrence_pattern: MapiCalendarRecurrencePatternDto = None, time_zone_struct: MapiCalendarTimeZoneDto = None):
        """
        Recurrence properties of calendar object.             
        :param appointment_time_zone_definition_recur: Time zone information that describes how to convert the meeting date and time on a recurring series to and from UTC.             
        :type appointment_time_zone_definition_recur: MapiCalendarTimeZoneDto
        :param clip_end: Date of the last instance.             
        :type clip_end: datetime
        :param clip_start: Date of the first instance.             
        :type clip_start: datetime
        :param is_exception: Value indicating whether the object represents an exception.             
        :type is_exception: bool
        :param recurrence_pattern: Recurrence pattern.             
        :type recurrence_pattern: MapiCalendarRecurrencePatternDto
        :param time_zone_struct: Time zone information for a recurring meeting.             
        :type time_zone_struct: MapiCalendarTimeZoneDto
        """

        self._appointment_time_zone_definition_recur = None
        self._clip_end = None
        self._clip_start = None
        self._is_exception = None
        self._recurrence_pattern = None
        self._time_zone_struct = None

        if appointment_time_zone_definition_recur is not None:
            self.appointment_time_zone_definition_recur = appointment_time_zone_definition_recur
        if clip_end is not None:
            self.clip_end = clip_end
        if clip_start is not None:
            self.clip_start = clip_start
        if is_exception is not None:
            self.is_exception = is_exception
        if recurrence_pattern is not None:
            self.recurrence_pattern = recurrence_pattern
        if time_zone_struct is not None:
            self.time_zone_struct = time_zone_struct


    @property
    def appointment_time_zone_definition_recur(self) -> MapiCalendarTimeZoneDto:
        """
        Time zone information that describes how to convert the meeting date and time on a recurring series to and from UTC.             

        :return: The appointment_time_zone_definition_recur of this MapiCalendarEventRecurrenceDto.
        :rtype: MapiCalendarTimeZoneDto
        """
        return self._appointment_time_zone_definition_recur

    @appointment_time_zone_definition_recur.setter
    def appointment_time_zone_definition_recur(self, appointment_time_zone_definition_recur: MapiCalendarTimeZoneDto):
        """
        Time zone information that describes how to convert the meeting date and time on a recurring series to and from UTC.             

        :param appointment_time_zone_definition_recur: The appointment_time_zone_definition_recur of this MapiCalendarEventRecurrenceDto.
        :type: MapiCalendarTimeZoneDto
        """
        self._appointment_time_zone_definition_recur = appointment_time_zone_definition_recur

    @property
    def clip_end(self) -> datetime:
        """
        Date of the last instance.             

        :return: The clip_end of this MapiCalendarEventRecurrenceDto.
        :rtype: datetime
        """
        return self._clip_end

    @clip_end.setter
    def clip_end(self, clip_end: datetime):
        """
        Date of the last instance.             

        :param clip_end: The clip_end of this MapiCalendarEventRecurrenceDto.
        :type: datetime
        """
        if clip_end is None:
            raise ValueError("Invalid value for `clip_end`, must not be `None`")
        self._clip_end = clip_end

    @property
    def clip_start(self) -> datetime:
        """
        Date of the first instance.             

        :return: The clip_start of this MapiCalendarEventRecurrenceDto.
        :rtype: datetime
        """
        return self._clip_start

    @clip_start.setter
    def clip_start(self, clip_start: datetime):
        """
        Date of the first instance.             

        :param clip_start: The clip_start of this MapiCalendarEventRecurrenceDto.
        :type: datetime
        """
        if clip_start is None:
            raise ValueError("Invalid value for `clip_start`, must not be `None`")
        self._clip_start = clip_start

    @property
    def is_exception(self) -> bool:
        """
        Value indicating whether the object represents an exception.             

        :return: The is_exception of this MapiCalendarEventRecurrenceDto.
        :rtype: bool
        """
        return self._is_exception

    @is_exception.setter
    def is_exception(self, is_exception: bool):
        """
        Value indicating whether the object represents an exception.             

        :param is_exception: The is_exception of this MapiCalendarEventRecurrenceDto.
        :type: bool
        """
        if is_exception is None:
            raise ValueError("Invalid value for `is_exception`, must not be `None`")
        self._is_exception = is_exception

    @property
    def recurrence_pattern(self) -> MapiCalendarRecurrencePatternDto:
        """
        Recurrence pattern.             

        :return: The recurrence_pattern of this MapiCalendarEventRecurrenceDto.
        :rtype: MapiCalendarRecurrencePatternDto
        """
        return self._recurrence_pattern

    @recurrence_pattern.setter
    def recurrence_pattern(self, recurrence_pattern: MapiCalendarRecurrencePatternDto):
        """
        Recurrence pattern.             

        :param recurrence_pattern: The recurrence_pattern of this MapiCalendarEventRecurrenceDto.
        :type: MapiCalendarRecurrencePatternDto
        """
        self._recurrence_pattern = recurrence_pattern

    @property
    def time_zone_struct(self) -> MapiCalendarTimeZoneDto:
        """
        Time zone information for a recurring meeting.             

        :return: The time_zone_struct of this MapiCalendarEventRecurrenceDto.
        :rtype: MapiCalendarTimeZoneDto
        """
        return self._time_zone_struct

    @time_zone_struct.setter
    def time_zone_struct(self, time_zone_struct: MapiCalendarTimeZoneDto):
        """
        Time zone information for a recurring meeting.             

        :param time_zone_struct: The time_zone_struct of this MapiCalendarEventRecurrenceDto.
        :type: MapiCalendarTimeZoneDto
        """
        self._time_zone_struct = time_zone_struct

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MapiCalendarEventRecurrenceDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="mapi_calendar_api.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

from __future__ import absolute_import

from AsposeEmailCloudSdk.api.api_base import ApiBase
from AsposeEmailCloudSdk.models import *


class MapiCalendarApi(ApiBase):
    """
    Aspose.Email Cloud API. MapiCalendarApi operations.

    """

    def __init__(self, api_client):
        super(MapiCalendarApi, self).__init__(api_client)

    def as_calendar_dto(self, mapi_calendar_dto: MapiCalendarDto) -> CalendarDto:
        """Converts MAPI calendar model to CalendarDto model.             

        :param mapi_calendar_dto: MAPI calendar model to convert.
        :type mapi_calendar_dto: MapiCalendarDto
        :return: CalendarDto
        """
        # verify the required parameter 'mapi_calendar_dto' is set
        if mapi_calendar_dto is None:
            raise ValueError("Missing the required parameter `mapi_calendar_dto` when calling `as_calendar_dto`")

        collection_formats = {}
        path = '/email/MapiCalendar/as-calendar-dto'

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['application/json'])
        body_params = mapi_calendar_dto
        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, None, None, header_params, None, body_params, None, None, auth_settings)

        return self._make_request(http_request_object, 'PUT', 'CalendarDto')

    def as_file(self, request: MapiCalendarAsFileRequest) -> str:
        """Converts MAPI calendar model to specified format and returns as file.             

        :param request: MAPI calendar model to convert.
        :type request: MapiCalendarAsFileRequest
        :return: str
        """
        # verify the required parameter 'request' is set
        if request is None:
            raise ValueError("Missing the required parameter `request` when calling `as_file`")

        collection_formats = {}
        path = '/email/MapiCalendar/as-file'

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['multipart/form-data'])
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['application/json'])
        body_params = request
        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, None, None, header_params, None, body_params, None, None, auth_settings)

        return self._make_request(http_request_object, 'PUT', 'file')

    def from_file(self, request: MapiCalendarFromFileRequest) -> MapiCalendarDto:
        """Converts calendar file to a MAPI model representation.             


        :param request: MapiCalendarFromFileRequest object with parameters
        :type request: MapiCalendarFromFileRequest
        :return: MapiCalendarDto
        """
        # verify the required parameter 'file' is set
        if request.file is None:
            raise ValueError("Missing the required parameter `file` when calling `from_file`")

        collection_formats = {}
        path = '/email/MapiCalendar/from-file'
        path_params = {}

        query_params = []

        form_params = []
        local_var_files = []
        if request.file is not None:
            local_var_files.append((self._lowercase_first_letter('File'), request.file))

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['multipart/form-data'])

        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, path_params, query_params, header_params, form_params, None, local_var_files,
                                          collection_formats, auth_settings)

        return self._make_request(http_request_object, 'PUT', 'MapiCalendarDto')

    def get(self, request: MapiCalendarGetRequest) -> MapiCalendarDto:
        """Get MAPI calendar document.             


        :param request: MapiCalendarGetRequest object with parameters
        :type request: MapiCalendarGetRequest
        :return: MapiCalendarDto
        """
        # verify the required parameter 'file_name' is set
        if request.file_name is None:
            raise ValueError("Missing the required parameter `file_name` when calling `get`")

        collection_formats = {}
        path = '/email/MapiCalendar'
        path_params = {}

        query_params = []
        path_parameter = '{' + self._lowercase_first_letter('fileName') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.file_name if request.file_name is not None else '')
        else:
            if request.file_name is not None:
                query_params.append((self._lowercase_first_letter('fileName'), request.file_name))
        path_parameter = '{' + self._lowercase_first_letter('folder') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.folder if request.folder is not None else '')
        else:
            if request.folder is not None:
                query_params.append((self._lowercase_first_letter('folder'), request.folder))
        path_parameter = '{' + self._lowercase_first_letter('storage') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.storage if request.storage is not None else '')
        else:
            if request.storage is not None:
                query_params.append((self._lowercase_first_letter('storage'), request.storage))

        form_params = []
        local_var_files = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['application/json'])

        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, path_params, query_params, header_params, form_params, None, local_var_files,
                                          collection_formats, auth_settings)

        return self._make_request(http_request_object, 'GET', 'MapiCalendarDto')

    def save(self, request: MapiCalendarSaveRequest):
        """Save MAPI Calendar to storage.             

        :param request: Calendar create/update request.
        :type request: MapiCalendarSaveRequest
        :return: None
        """
        # verify the required parameter 'request' is set
        if request is None:
            raise ValueError("Missing the required parameter `request` when calling `save`")

        collection_formats = {}
        path = '/email/MapiCalendar'

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['application/json'])
        body_params = request
        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, None, None, header_params, None, body_params, None, None, auth_settings)

        return self._make_request(http_request_object, 'PUT', None)




#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="email_get_list_request.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

from AsposeEmailCloudSdk.models import *


class EmailGetListRequest(object):
    """
    Request model for email_get_list operation.
    Initializes a new instance.

    :param format: Email document format. Enum, available values: Eml, Msg, MsgUnicode, Mhtml, Html, Tnef, Oft
    :type format: str
    :param folder: Path to folder in storage.
    :type folder: str
    :param storage: Storage name.
    :type storage: str
    :param items_per_page: Count of items on page.
    :type items_per_page: int
    :param page_number: Page number.
    :type page_number: int
    """

    def __init__(self, format: str, folder: str = None, storage: str = None, items_per_page: int = None, page_number: int = None):
        """
        Request model for email_get_list operation.
        Initializes a new instance.

        :param format: Email document format. Enum, available values: Eml, Msg, MsgUnicode, Mhtml, Html, Tnef, Oft
        :type format: str
        :param folder: Path to folder in storage.
        :type folder: str
        :param storage: Storage name.
        :type storage: str
        :param items_per_page: Count of items on page.
        :type items_per_page: int
        :param page_number: Page number.
        :type page_number: int
        """

        self.format = format
        self.folder = folder
        self.storage = storage
        self.items_per_page = items_per_page
        self.page_number = page_number




#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="AiNameParsedRequest.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six
from typing import List, Set, Dict, Tuple, Optional
from datetime import datetime

from AsposeEmailCloudSdk.models.ai_name_component import AiNameComponent
from AsposeEmailCloudSdk.models.ai_name_cultural_context import AiNameCulturalContext


class AiNameParsedRequest(object):
    """Parsed name request model             
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cultural_context': 'AiNameCulturalContext',
        'format': 'str',
        'parsed_name': 'list[AiNameComponent]'
    }

    attribute_map = {
        'cultural_context': 'culturalContext',
        'format': 'format',
        'parsed_name': 'parsedName'
    }

    def __init__(self, cultural_context: AiNameCulturalContext = None, format: str = None, parsed_name: List[AiNameComponent] = None):
        """
        Parsed name request model             
        :param cultural_context: AiName parser cultural context             
        :type cultural_context: AiNameCulturalContext
        :param format: Format of the name. Predefined format can be used by ID, or custom format can be specified. Predefined formats:      /format/default/ (= '%t%F%m%N%L%p')     /format/FN+LN/ (= '%F%L')     /format/title+FN+LN/ (= '%t%F%L')     /format/FN+MN+LN/ (= '%F%M%N%L')     /format/title+FN+MN+LN/ (= '%t%F%M%N%L')     /format/FN+MI+LN/ (= '%F%m%N%L')     /format/title+FN+MI+LN/ (= '%t%F%m%N%L')     /format/LN/ (= '%L')     /format/title+LN/ (= '%t%L')     /format/LN+FN+MN/ (= '%L,%F%M%N')     /format/LN+title+FN+MN/ (= '%L,%t%F%M%N')     /format/LN+FN+MI/ (= '%L,%F%m%N')     /format/LN+title+FN+MI/ (= '%L,%t%F%m%N')  Custom format string - custom combination of characters and the next term placeholders:      '%t' - Title (prefix)     '%F' - First name     '%f' - First initial     '%M' - Middle name(s)     '%m' - Middle initial(s)     '%N' - Nickname     '%L' - Last name     '%l' - Last initial     '%p' - Postfix  If no value for format option was provided, its default value is '%t%F%m%N%L%p'             
        :type format: str
        :param parsed_name: Parsed name             
        :type parsed_name: List[AiNameComponent]
        """

        self._cultural_context = None
        self._format = None
        self._parsed_name = None

        if cultural_context is not None:
            self.cultural_context = cultural_context
        if format is not None:
            self.format = format
        if parsed_name is not None:
            self.parsed_name = parsed_name


    @property
    def cultural_context(self) -> AiNameCulturalContext:
        """
        AiName parser cultural context             

        :return: The cultural_context of this AiNameParsedRequest.
        :rtype: AiNameCulturalContext
        """
        return self._cultural_context

    @cultural_context.setter
    def cultural_context(self, cultural_context: AiNameCulturalContext):
        """
        AiName parser cultural context             

        :param cultural_context: The cultural_context of this AiNameParsedRequest.
        :type: AiNameCulturalContext
        """
        self._cultural_context = cultural_context

    @property
    def format(self) -> str:
        """
        Format of the name. Predefined format can be used by ID, or custom format can be specified. Predefined formats:      /format/default/ (= '%t%F%m%N%L%p')     /format/FN+LN/ (= '%F%L')     /format/title+FN+LN/ (= '%t%F%L')     /format/FN+MN+LN/ (= '%F%M%N%L')     /format/title+FN+MN+LN/ (= '%t%F%M%N%L')     /format/FN+MI+LN/ (= '%F%m%N%L')     /format/title+FN+MI+LN/ (= '%t%F%m%N%L')     /format/LN/ (= '%L')     /format/title+LN/ (= '%t%L')     /format/LN+FN+MN/ (= '%L,%F%M%N')     /format/LN+title+FN+MN/ (= '%L,%t%F%M%N')     /format/LN+FN+MI/ (= '%L,%F%m%N')     /format/LN+title+FN+MI/ (= '%L,%t%F%m%N')  Custom format string - custom combination of characters and the next term placeholders:      '%t' - Title (prefix)     '%F' - First name     '%f' - First initial     '%M' - Middle name(s)     '%m' - Middle initial(s)     '%N' - Nickname     '%L' - Last name     '%l' - Last initial     '%p' - Postfix  If no value for format option was provided, its default value is '%t%F%m%N%L%p'             

        :return: The format of this AiNameParsedRequest.
        :rtype: str
        """
        return self._format

    @format.setter
    def format(self, format: str):
        """
        Format of the name. Predefined format can be used by ID, or custom format can be specified. Predefined formats:      /format/default/ (= '%t%F%m%N%L%p')     /format/FN+LN/ (= '%F%L')     /format/title+FN+LN/ (= '%t%F%L')     /format/FN+MN+LN/ (= '%F%M%N%L')     /format/title+FN+MN+LN/ (= '%t%F%M%N%L')     /format/FN+MI+LN/ (= '%F%m%N%L')     /format/title+FN+MI+LN/ (= '%t%F%m%N%L')     /format/LN/ (= '%L')     /format/title+LN/ (= '%t%L')     /format/LN+FN+MN/ (= '%L,%F%M%N')     /format/LN+title+FN+MN/ (= '%L,%t%F%M%N')     /format/LN+FN+MI/ (= '%L,%F%m%N')     /format/LN+title+FN+MI/ (= '%L,%t%F%m%N')  Custom format string - custom combination of characters and the next term placeholders:      '%t' - Title (prefix)     '%F' - First name     '%f' - First initial     '%M' - Middle name(s)     '%m' - Middle initial(s)     '%N' - Nickname     '%L' - Last name     '%l' - Last initial     '%p' - Postfix  If no value for format option was provided, its default value is '%t%F%m%N%L%p'             

        :param format: The format of this AiNameParsedRequest.
        :type: str
        """
        self._format = format

    @property
    def parsed_name(self) -> List[AiNameComponent]:
        """
        Parsed name             

        :return: The parsed_name of this AiNameParsedRequest.
        :rtype: list[AiNameComponent]
        """
        return self._parsed_name

    @parsed_name.setter
    def parsed_name(self, parsed_name: List[AiNameComponent]):
        """
        Parsed name             

        :param parsed_name: The parsed_name of this AiNameParsedRequest.
        :type: list[AiNameComponent]
        """
        if parsed_name is None:
            raise ValueError("Invalid value for `parsed_name`, must not be `None`")
        self._parsed_name = parsed_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AiNameParsedRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="PostalAddress.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six
from typing import List, Set, Dict, Tuple, Optional
from datetime import datetime

from AsposeEmailCloudSdk.models.enum_with_custom_of_postal_address_category import EnumWithCustomOfPostalAddressCategory


class PostalAddress(object):
    """A postal address             
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'address': 'str',
        'category': 'EnumWithCustomOfPostalAddressCategory',
        'city': 'str',
        'country': 'str',
        'country_code': 'str',
        'is_mailing_address': 'bool',
        'postal_code': 'str',
        'post_office_box': 'str',
        'preferred': 'bool',
        'state_or_province': 'str',
        'street': 'str'
    }

    attribute_map = {
        'address': 'address',
        'category': 'category',
        'city': 'city',
        'country': 'country',
        'country_code': 'countryCode',
        'is_mailing_address': 'isMailingAddress',
        'postal_code': 'postalCode',
        'post_office_box': 'postOfficeBox',
        'preferred': 'preferred',
        'state_or_province': 'stateOrProvince',
        'street': 'street'
    }

    def __init__(self, address: str = None, category: EnumWithCustomOfPostalAddressCategory = None, city: str = None, country: str = None, country_code: str = None, is_mailing_address: bool = None, postal_code: str = None, post_office_box: str = None, preferred: bool = None, state_or_province: str = None, street: str = None):
        """
        A postal address             
        :param address: Address.             
        :type address: str
        :param category: Address category.             
        :type category: EnumWithCustomOfPostalAddressCategory
        :param city: Address's city.             
        :type city: str
        :param country: Address's country.             
        :type country: str
        :param country_code: Country code.             
        :type country_code: str
        :param is_mailing_address: Defines whether address may be used for mailing.             
        :type is_mailing_address: bool
        :param postal_code: Postal code.             
        :type postal_code: str
        :param post_office_box: Post Office box.             
        :type post_office_box: str
        :param preferred: Defines whether postal address is preferred.             
        :type preferred: bool
        :param state_or_province: Address's region.             
        :type state_or_province: str
        :param street: Address's street.             
        :type street: str
        """

        self._address = None
        self._category = None
        self._city = None
        self._country = None
        self._country_code = None
        self._is_mailing_address = None
        self._postal_code = None
        self._post_office_box = None
        self._preferred = None
        self._state_or_province = None
        self._street = None

        if address is not None:
            self.address = address
        if category is not None:
            self.category = category
        if city is not None:
            self.city = city
        if country is not None:
            self.country = country
        if country_code is not None:
            self.country_code = country_code
        if is_mailing_address is not None:
            self.is_mailing_address = is_mailing_address
        if postal_code is not None:
            self.postal_code = postal_code
        if post_office_box is not None:
            self.post_office_box = post_office_box
        if preferred is not None:
            self.preferred = preferred
        if state_or_province is not None:
            self.state_or_province = state_or_province
        if street is not None:
            self.street = street


    @property
    def address(self) -> str:
        """
        Address.             

        :return: The address of this PostalAddress.
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address: str):
        """
        Address.             

        :param address: The address of this PostalAddress.
        :type: str
        """
        self._address = address

    @property
    def category(self) -> EnumWithCustomOfPostalAddressCategory:
        """
        Address category.             

        :return: The category of this PostalAddress.
        :rtype: EnumWithCustomOfPostalAddressCategory
        """
        return self._category

    @category.setter
    def category(self, category: EnumWithCustomOfPostalAddressCategory):
        """
        Address category.             

        :param category: The category of this PostalAddress.
        :type: EnumWithCustomOfPostalAddressCategory
        """
        self._category = category

    @property
    def city(self) -> str:
        """
        Address's city.             

        :return: The city of this PostalAddress.
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city: str):
        """
        Address's city.             

        :param city: The city of this PostalAddress.
        :type: str
        """
        self._city = city

    @property
    def country(self) -> str:
        """
        Address's country.             

        :return: The country of this PostalAddress.
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country: str):
        """
        Address's country.             

        :param country: The country of this PostalAddress.
        :type: str
        """
        self._country = country

    @property
    def country_code(self) -> str:
        """
        Country code.             

        :return: The country_code of this PostalAddress.
        :rtype: str
        """
        return self._country_code

    @country_code.setter
    def country_code(self, country_code: str):
        """
        Country code.             

        :param country_code: The country_code of this PostalAddress.
        :type: str
        """
        self._country_code = country_code

    @property
    def is_mailing_address(self) -> bool:
        """
        Defines whether address may be used for mailing.             

        :return: The is_mailing_address of this PostalAddress.
        :rtype: bool
        """
        return self._is_mailing_address

    @is_mailing_address.setter
    def is_mailing_address(self, is_mailing_address: bool):
        """
        Defines whether address may be used for mailing.             

        :param is_mailing_address: The is_mailing_address of this PostalAddress.
        :type: bool
        """
        if is_mailing_address is None:
            raise ValueError("Invalid value for `is_mailing_address`, must not be `None`")
        self._is_mailing_address = is_mailing_address

    @property
    def postal_code(self) -> str:
        """
        Postal code.             

        :return: The postal_code of this PostalAddress.
        :rtype: str
        """
        return self._postal_code

    @postal_code.setter
    def postal_code(self, postal_code: str):
        """
        Postal code.             

        :param postal_code: The postal_code of this PostalAddress.
        :type: str
        """
        self._postal_code = postal_code

    @property
    def post_office_box(self) -> str:
        """
        Post Office box.             

        :return: The post_office_box of this PostalAddress.
        :rtype: str
        """
        return self._post_office_box

    @post_office_box.setter
    def post_office_box(self, post_office_box: str):
        """
        Post Office box.             

        :param post_office_box: The post_office_box of this PostalAddress.
        :type: str
        """
        self._post_office_box = post_office_box

    @property
    def preferred(self) -> bool:
        """
        Defines whether postal address is preferred.             

        :return: The preferred of this PostalAddress.
        :rtype: bool
        """
        return self._preferred

    @preferred.setter
    def preferred(self, preferred: bool):
        """
        Defines whether postal address is preferred.             

        :param preferred: The preferred of this PostalAddress.
        :type: bool
        """
        if preferred is None:
            raise ValueError("Invalid value for `preferred`, must not be `None`")
        self._preferred = preferred

    @property
    def state_or_province(self) -> str:
        """
        Address's region.             

        :return: The state_or_province of this PostalAddress.
        :rtype: str
        """
        return self._state_or_province

    @state_or_province.setter
    def state_or_province(self, state_or_province: str):
        """
        Address's region.             

        :param state_or_province: The state_or_province of this PostalAddress.
        :type: str
        """
        self._state_or_province = state_or_province

    @property
    def street(self) -> str:
        """
        Address's street.             

        :return: The street of this PostalAddress.
        :rtype: str
        """
        return self._street

    @street.setter
    def street(self, street: str):
        """
        Address's street.             

        :param street: The street of this PostalAddress.
        :type: str
        """
        self._street = street

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PostalAddress):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
